/*
 * Name:    mt_motor.c
 *
 * Purpose: Tcl interface to generic MX motor functions.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 1999-2002, 2004-2006 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>

#include <tcl.h>

#include "mx_util.h"
#include "mx_record.h"
#include "mx_motor.h"
#include "mx_handle.h"
#include "mx_tcl.h"
#include "mx_tcl_private.h"

MX_EXPORT int
Mx_motor_is_busy_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	mx_bool_type busy;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_is_busy record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_is_busy( record, &busy );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetIntObj( resultPtr, (int) busy );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_move_absolute_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	static const char fname[] = "Mx_motor_move_absolute_cmd()";

	MX_RECORD *record;
	int tcl_status;
	double destination;
	mx_status_type mx_status;

	if ( objc != 3 ) {
		Tcl_WrongNumArgs( interp, 2, objv,
		"Usage: motor_move_absolute record_handle destination" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	tcl_status = Tcl_GetDoubleFromObj( interp, objv[2], &destination );

	if ( tcl_status != TCL_OK )
		return mxtcl_object_parse_error(
					interp, objv[2], "double", fname );

	mx_status = mx_motor_move_absolute( record, destination, 0 );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_get_position_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	double position;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_get_position record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_get_position( record, &position );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetDoubleObj( resultPtr, position );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_set_position_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	static const char fname[] = "Mx_motor_set_position_cmd()";

	MX_RECORD *record;
	int tcl_status;
	double set_position;
	mx_status_type mx_status;

	if ( objc != 3 ) {
		Tcl_WrongNumArgs( interp, 2, objv,
		"Usage: motor_set_position record_handle set_position" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	tcl_status = Tcl_GetDoubleFromObj( interp, objv[2], &set_position );

	if ( tcl_status != TCL_OK )
		return mxtcl_object_parse_error(
					interp, objv[2], "double", fname );

	mx_status = mx_motor_set_position( record, set_position );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_soft_abort_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	MX_RECORD *record;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_soft_abort record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_soft_abort( record );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_immediate_abort_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	MX_RECORD *record;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_immediate_abort record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_immediate_abort( record );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_positive_limit_hit_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	mx_bool_type limit_hit;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_positive_limit_hit record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_positive_limit_hit( record, &limit_hit );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetIntObj( resultPtr, (int) limit_hit );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_negative_limit_hit_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	mx_bool_type limit_hit;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_negative_limit_hit record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_negative_limit_hit( record, &limit_hit );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetIntObj( resultPtr, (int) limit_hit );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_find_home_position_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	static const char fname[] = "Mx_motor_find_home_position()";

	MX_RECORD *record;
	int tcl_status;
	long direction;
	mx_status_type mx_status;

	if ( objc != 3 ) {
		Tcl_WrongNumArgs( interp, 2, objv,
		"Usage: motor_find_home_position record_handle direction" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	tcl_status = Tcl_GetLongFromObj( interp, objv[2], &direction );

	if ( tcl_status != TCL_OK )
		return mxtcl_object_parse_error(
					interp, objv[2], "long", fname );

	mx_status = mx_motor_find_home_position( record, (int) direction );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_constant_velocity_move_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	static const char fname[] = "Mx_motor_constant_velocity_move()";

	MX_RECORD *record;
	int tcl_status;
	long direction;
	mx_status_type mx_status;

	if ( objc != 3 ) {
		Tcl_WrongNumArgs( interp, 2, objv,
		"Usage: motor_constant_velocity_move record_handle direction" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	tcl_status = Tcl_GetLongFromObj( interp, objv[2], &direction );

	if ( tcl_status != TCL_OK )
		return mxtcl_object_parse_error(
					interp, objv[2], "long", fname );

	mx_status = mx_motor_constant_velocity_move( record, (int) direction );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_get_status_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	unsigned long motor_status;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_get_status record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_get_status( record, &motor_status );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetLongObj( resultPtr, motor_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_get_extended_status_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr, *temp_object;
	MX_RECORD *record;
	double motor_position;
	unsigned long motor_status;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_get_extended_status record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_get_extended_status( record,
					&motor_position, &motor_status );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	/* The extended status is returned as a 2-element list. */

	temp_object = Tcl_NewObj();

	resultPtr = Tcl_GetObjResult( interp );

	Tcl_SetListObj( resultPtr, 0, NULL );

	/* Insert the motor position and status into the list. */

	Tcl_SetDoubleObj( temp_object, motor_position );
	Tcl_ListObjAppendElement( interp, resultPtr, temp_object );

	Tcl_SetLongObj( temp_object, motor_status );
	Tcl_ListObjAppendElement( interp, resultPtr, temp_object );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_get_speed_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	double speed;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_get_speed record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_get_speed( record, &speed );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetDoubleObj( resultPtr, speed );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_set_speed_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	static const char fname[] = "Mx_motor_set_speed()";

	MX_RECORD *record;
	int tcl_status;
	double speed;
	mx_status_type mx_status;

	if ( objc != 3 ) {
		Tcl_WrongNumArgs( interp, 2, objv,
		"Usage: motor_set_speed record_handle speed" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	tcl_status = Tcl_GetDoubleFromObj( interp, objv[2], &speed );

	if ( tcl_status != TCL_OK )
		return mxtcl_object_parse_error(
					interp, objv[2], "double", fname );

	mx_status = mx_motor_set_speed( record, speed );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_get_base_speed_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	double speed;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_get_base_speed record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_get_base_speed( record, &speed );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetDoubleObj( resultPtr, speed );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_set_base_speed_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	static const char fname[] = "Mx_motor_set_base_speed()";

	MX_RECORD *record;
	int tcl_status;
	double speed;
	mx_status_type mx_status;

	if ( objc != 3 ) {
		Tcl_WrongNumArgs( interp, 2, objv,
		"Usage: motor_set_base_speed record_handle speed" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	tcl_status = Tcl_GetDoubleFromObj( interp, objv[2], &speed );

	if ( tcl_status != TCL_OK )
		return mxtcl_object_parse_error(
					interp, objv[2], "double", fname );

	mx_status = mx_motor_set_base_speed( record, speed );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_get_maximum_speed_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	double speed;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_get_maximum_speed record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_get_maximum_speed( record, &speed );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetDoubleObj( resultPtr, speed );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_set_maximum_speed_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	static const char fname[] = "Mx_motor_set_maximum_speed()";

	MX_RECORD *record;
	int tcl_status;
	double speed;
	mx_status_type mx_status;

	if ( objc != 3 ) {
		Tcl_WrongNumArgs( interp, 2, objv,
		"Usage: motor_set_maximum_speed record_handle speed" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	tcl_status = Tcl_GetDoubleFromObj( interp, objv[2], &speed );

	if ( tcl_status != TCL_OK )
		return mxtcl_object_parse_error(
					interp, objv[2], "double", fname );

	mx_status = mx_motor_set_maximum_speed( record, speed );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_get_acceleration_type_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	long acceleration_type;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_get_acceleration_type record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_get_acceleration_type( record,
							&acceleration_type );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetLongObj( resultPtr, acceleration_type );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_get_raw_acceleration_parameters_cmd(
			ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr, *temp_object;
	MX_RECORD *record;
	double parameter_array[MX_MOTOR_NUM_ACCELERATION_PARAMS];
	int i;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_get_raw_acceleration_parameters record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_get_raw_acceleration_parameters(
						record, parameter_array );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	/* WML: I don't know yet if the following works. */

	temp_object = Tcl_NewObj();

	resultPtr = Tcl_GetObjResult( interp );

	Tcl_SetListObj( resultPtr, 0, NULL );

	for ( i = 0; i < MX_MOTOR_NUM_ACCELERATION_PARAMS; i++ ) {

		Tcl_SetDoubleObj( temp_object, parameter_array[i] );

		Tcl_ListObjAppendElement( interp, resultPtr, temp_object );
	}

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_set_raw_acceleration_parameters_cmd(
			ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	static const char fname[] = 
			"Mx_motor_set_raw_acceleration_parameters()";

	MX_RECORD *record;
	int i, list_objc, tcl_status;
	Tcl_Obj **list_objv;
	double parameter_array[MX_MOTOR_NUM_ACCELERATION_PARAMS];
	mx_status_type mx_status;

	if ( objc != 3 ) {
		Tcl_WrongNumArgs( interp, 2, objv,
"Usage: motor_set_raw_acceleration_parameters record_handle parameter_list");
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	/* WML: I don't know yet if the following works. */

	tcl_status = Tcl_ListObjGetElements( interp, objv[2],
			&list_objc, &list_objv );

	if ( tcl_status != TCL_OK )
		return TCL_ERROR;

	if ( list_objc < MX_MOTOR_NUM_ACCELERATION_PARAMS ) {
		mx_status = mx_error( MXE_ILLEGAL_ARGUMENT, fname,
"Too few acceleration parameters were passed.  Four parameters are required.");

		return mxtcl_error( interp, mx_status );
	}

	for ( i = 0; i < MX_MOTOR_NUM_ACCELERATION_PARAMS; i++ ) {

		tcl_status = Tcl_GetDoubleFromObj( interp,
						list_objv[i],
						&(parameter_array[i]) );

		if ( tcl_status != TCL_OK )
			return mxtcl_object_parse_error(
					interp, objv[2], "double", fname );
	}

	mx_status = mx_motor_set_raw_acceleration_parameters(
						record, parameter_array );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

MX_EXPORT int
Mx_motor_home_search_succeeded_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	mx_bool_type home_search_succeeded;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: motor_home_search_succeeded record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	mx_status = mx_motor_home_search_succeeded( record,
						&home_search_succeeded );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetIntObj( resultPtr, (int) home_search_succeeded );

	return TCL_OK;
}

